@@ -2,7 +2,7 @@
 
 use anchor_lang::prelude::*;
 use vipers::validate::Validate;
-use vipers::{assert_ata, assert_keys, invariant};
+use vipers::{assert_ata, assert_keys_eq, invariant};
 
 use crate::ClaimRewards;
 use crate::WithdrawTokens;
@@ -19,7 +19,7 @@ impl<'info> Validate<'info> for NewPool<'info> {
     fn validate(&self) -> ProgramResult {
         // replica_mint checks are now redundant
         // since it is now an associated mint
-        assert_keys!(
+        assert_keys_eq!(
             self.replica_mint.mint_authority.unwrap(),
             self.pool,
             "replica_mint.mint_authority"
@@ -55,8 +55,8 @@ impl<'info> Validate<'info> for InitMiner<'info> {
             InvalidMiner
         );
 
-        assert_keys!(self.mm.pool, self.pool, "mm.pool");
-        assert_keys!(
+        assert_keys_eq!(self.mm.pool, self.pool, "mm.pool");
+        assert_keys_eq!(
             self.quarry.rewarder_key,
             *self.rewarder,
             "quarry.rewarder_key"
@@ -76,7 +76,7 @@ impl<'info> Validate<'info> for WithdrawTokens<'info> {
     fn validate(&self) -> ProgramResult {
         let withdraw_mint = self.mm_token_account.mint;
 
-        assert_keys!(self.withdraw_mint, withdraw_mint, "withdraw_mint");
+        assert_keys_eq!(self.withdraw_mint, withdraw_mint, "withdraw_mint");
         // cannot withdraw a replica mint.
         require!(
             self.withdraw_mint.key() != self.pool.replica_mint,
@@ -88,8 +88,8 @@ impl<'info> Validate<'info> for WithdrawTokens<'info> {
             require!(self.mm.replica_balance == 0, OutstandingReplicaTokens);
         }
 
-        assert_keys!(self.owner, self.mm.owner, "owner");
-        assert_keys!(self.pool, self.mm.pool, "pool");
+        assert_keys_eq!(self.owner, self.mm.owner, "owner");
+        assert_keys_eq!(self.pool, self.mm.pool, "pool");
 
         assert_ata!(
             self.mm_token_account,
@@ -97,7 +97,7 @@ impl<'info> Validate<'info> for WithdrawTokens<'info> {
             withdraw_mint,
             "mm_token_account"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.token_destination.mint,
             withdraw_mint,
             "token_destination.mint"
@@ -111,17 +111,17 @@ impl<'info> Validate<'info> for ClaimRewards<'info> {
     fn validate(&self) -> ProgramResult {
         self.stake.validate()?;
 
-        assert_keys!(
+        assert_keys_eq!(
             self.minter.mint_wrapper,
             *self.mint_wrapper,
             "minter.mint_wrapper"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.minter.minter_authority,
             *self.stake.rewarder,
             "minter.minter_authority"
         );
-        assert_keys!(
+        assert_keys_eq!(
             *self.rewards_token_mint,
             self.mint_wrapper.token_mint,
             "mint_wrapper.token_mint"
@@ -132,12 +132,12 @@ impl<'info> Validate<'info> for ClaimRewards<'info> {
             *self.rewards_token_mint,
             "rewards_token_account"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.claim_fee_token_account.mint,
             *self.rewards_token_mint,
             "claim_fee_token_account.mint"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.stake_token_account.mint,
             self.stake.quarry.token_mint_key,
             "stake_token_account.mint"
@@ -158,8 +158,8 @@ impl<'info> Validate<'info> for QuarryStakePrimary<'info> {
         // For primary staking:
         // - quarry is a quarry, staking the `primary_mint`
 
-        assert_keys!(self.mm_owner, self.stake.mm.owner, "mm_owner");
-        assert_keys!(
+        assert_keys_eq!(self.mm_owner, self.stake.mm.owner, "mm_owner");
+        assert_keys_eq!(
             self.stake.quarry.token_mint_key,
             self.stake.pool.primary_mint,
             "stake.quarry.token_mint_key"
@@ -182,14 +182,14 @@ impl<'info> Validate<'info> for QuarryStakeReplica<'info> {
         // For replica staking:
         // - rewarder is any rewarder
         // - quarry is a quarry staking the `replica_mint`
-        assert_keys!(self.mm_owner, self.stake.mm.owner, "mm_owner");
+        assert_keys_eq!(self.mm_owner, self.stake.mm.owner, "mm_owner");
 
-        assert_keys!(
+        assert_keys_eq!(
             self.stake.pool.replica_mint,
             self.replica_mint,
             "stake.pool.replica_mint"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.stake.quarry.token_mint_key,
             self.replica_mint,
             "stake.quarry.token_mint_key"
@@ -207,12 +207,12 @@ impl<'info> Validate<'info> for QuarryStakeReplica<'info> {
 
 impl<'info> Validate<'info> for QuarryStake<'info> {
     fn validate(&self) -> ProgramResult {
-        assert_keys!(self.mm.pool, self.pool, "mm.pool");
+        assert_keys_eq!(self.mm.pool, self.pool, "mm.pool");
 
-        assert_keys!(*self.rewarder, self.quarry.rewarder_key, "rewarder");
-        assert_keys!(*self.quarry, self.miner.quarry_key, "quarry");
-        assert_keys!(self.miner.authority, self.mm, "miner.authority");
-        assert_keys!(self.miner_vault, self.miner.token_vault_key, "miner_vault");
+        assert_keys_eq!(*self.rewarder, self.quarry.rewarder_key, "rewarder");
+        assert_keys_eq!(*self.quarry, self.miner.quarry_key, "quarry");
+        assert_keys_eq!(self.miner.authority, self.mm, "miner.authority");
+        assert_keys_eq!(self.miner_vault, self.miner.token_vault_key, "miner_vault");
         assert_ata!(
             self.miner_vault,
             *self.miner,
